# -*- coding: utf-8 -*-
from django.conf import settings
from django.utils.translation import ugettext as _
from django.contrib import admin

from jmb.core.admin.options import ExtendibleModelAdmin

from jmb.content_file.models import ContentFileCategory, ContentFile


class ContentFileCategoryAdmin(ExtendibleModelAdmin):
    list_display = ('get_status_icon', 'name', 'slug', 'get_edit_icon')
    prepopulated_fields = {"slug": ("name",)}
    fieldsets = (
        (_('logs admin'), {
            'fields': (
                'creator', 'date_create', 'last_modifier', 'date_last_modify',
            ),
            'classes': (
                'collapse',
            )
        }),
        (_('Ordering'), {
            'fields': ('ordering',),
            'classes': ('collapse',),
        }),
        (_('general admin'), {
            'fields': ('status',),
        }),
        (None, {"fields": ("name", "slug"), }),
    )


class ContentFileAdmin(ExtendibleModelAdmin):
    prepopulated_fields = {"slug": ("name",)}
    list_display = (
        'get_status_icon', 'name', 'date_content',
        'get_string_categories',
        'get_edit_icon',
    )
    fieldsets = (
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
            'classes': ('collapse',)
        }),
        (_('Ordering'), {
            'fields': ('ordering',),
            'classes': ('collapse',),
        }),
        (None, {
            'fields': ('status', 'categories',),
        }),
        (None, {
            "fields": (
                ('name', 'slug',),
                ('title', 'short_description',),
                ('content_file','small_image',),
                ('date_content',),
                'note',
            ),
        }),
        (_('Publication date'), {
            'fields': ('pub_date',),
            'classes': ('collapse',),
        }),
    )
    advanced_search_fields = (
        ('name__icontains',),
        ('categories__in',),
    )


admin.site.register(ContentFileCategory, ContentFileCategoryAdmin)
admin.site.register(ContentFile, ContentFileAdmin)
