# -*- coding: utf-8 -*-
from django.conf import settings
from django.db import models
from django.utils.translation import ugettext as _
from cms.models.pluginmodel import CMSPlugin
from jmb.core.db.models import StatusModel


class ContentFileSettings(CMSPlugin, StatusModel):
    title = models.CharField(
        max_length=100,
        null=True, blank=True,
        verbose_name=_("title"),
    )
    slug = models.SlugField(
        max_length=100,
        verbose_name=_("slug")
    )
    content_file_list_slug = models.SlugField(
        max_length=100,
        null=True, blank=True,
        verbose_name=_("content files list slug"),
        help_text=_("Slug pagina lista dei files"),
    )
    template_name = models.CharField(
        max_length=100,
        choices=settings.CONTENT_FILES_CMSPLUGIN_LIST_TEMPLATES
    )
    show_if_authenticated = models.CharField(
        max_length=100,
        choices=settings.CONTENT_FILES_CMSPLUGIN_SHOW_IF_AUTHENTICATED,
        verbose_name=_('Show if autenticated'),
        help_text=_("Show plugin if user is authenticated")
    )
    ordering = models.CharField(
        max_length=100,
        default='ordering, -date_content, title',
        verbose_name=_('Files ordering')
    )
    objects_limit = models.IntegerField(
        blank=True, null=True,
        verbose_name=_("Objects number limit"),
    )
    objects_per_page = models.IntegerField(
        default=10,
        verbose_name=_('Objects per page')
    )
    adjacent_pages = models.IntegerField(
        default=2,
        verbose_name=_('Adjacent pages')
    )

    class Meta:
        app_label = "content_file"

    def __unicode__(self):
        return "%s: %s %s - %s" % (
            self.id, ('On - ' if self.status else 'Off - '), self._meta.app_label,
            self.get_template_name_display()
        )

    def has_title(self):
        if not self.title:
            return False
        return True if self.title.strip() != "" else False