# coding: utf-8
import os

from django.conf import settings
from django.contrib.auth.models import User
from django.core.urlresolvers import reverse
from django.db import models
from django.template.defaultfilters import slugify
from django.utils.translation import ugettext_lazy as _

from jmb.core.db.models import DateModel, UserModel, StatusModel, OrderedModel
from jmb.content.models import ContentAbstract, TranslationContentAbstract, CategoryAbstract


class ContentFileCategory(CategoryAbstract):
    class Meta:
        verbose_name = _('File Category')
        verbose_name_plural = _('File Categories')


class ContentFile(ContentAbstract):

    def get_upload_path_small(self, filename):
        filename = slugify(filename)
        directory = filename[0:3]
        return os.path.join(directory, filename)

    def get_upload_path_big(self, filename):
        filename = slugify(filename)
        directory = filename[0:3]
        return os.path.join(directory, filename)

    status = models.IntegerField(
        choices=settings.CONTENT_FILE_FILE_STATO_CHOICES,
        verbose_name=_('status'),
        default=0
    )
    categories = models.ManyToManyField(
        ContentFileCategory,
        null=True,
        blank=True,
        related_name="files",
        verbose_name=_('Categories')
    )
    slug = models.SlugField(
        max_length=255,
        verbose_name=_('Slug'),
        unique=True,
    )
    title = models.CharField(
        max_length=100,
        null=True, blank=True,
        verbose_name=_("title"),
    )
    short_description = models.CharField(
        max_length=100,
        null=True, blank=True,
        verbose_name=_("short description"),
    )
    content_file = models.FileField(
        upload_to=get_upload_path_small,
        blank=True, null=True,
        verbose_name=_("File")
    )
    pub_date = models.DateTimeField(
        blank=True,
        null=True,
        verbose_name=_('Publication date'),
    )
    small_image = models.ImageField(
        upload_to=get_upload_path_small,
        blank=True, null=True,
        verbose_name=_("Small Image")
    )

    def get_string_categories(self):
        category_list = []
        for category in self.categories.all():
            category_list.append(category.name)
        return ", ".join(category_list)

    get_string_categories.short_description = "Categoria"

    class Meta:
        verbose_name = _('File')
        verbose_name_plural = _('Files')
        ordering = ('-date_content',)

    def __unicode__(self):
        return u"%s: %s" % (self.date_content, self.name)

if settings.CMS_ENABLED:
    import jmb.content_file.cms.models

